# InspectionSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**inspection_date** | **datetime** |  | 
**inspection_response_type** | [**InspectionResponseTypeResponse**](InspectionResponseTypeResponse.md) |  | 
**inspection_response_type_string** | **str** |  | 
**inspection_reference_number** | **str** |  | [optional] 
**inspection_type** | [**InspectionTypeResponse**](InspectionTypeResponse.md) |  | 
**inspection_type_string** | **str** |  | 
**inspection_status** | [**InspectionStatusResponse**](InspectionStatusResponse.md) |  | 
**inspection_status_string** | **str** |  | 
**inspection_category** | **AllOfInspectionSummaryResponseInspectionCategory** |  | [optional] 
**inspection_category_string** | **str** |  | [optional] 
**inspection_outcome** | **AllOfInspectionSummaryResponseInspectionOutcome** |  | [optional] 
**inspection_outcome_string** | **str** |  | [optional] 
**reinspection_date_time** | **datetime** |  | [optional] 
**auto_acceptance_due_date** | **datetime** |  | [optional] 
**ha_response_status** | [**InspectionOutcomeStatusTypeResponse**](InspectionOutcomeStatusTypeResponse.md) |  | [optional] 
**ha_response_status_string** | **str** |  | [optional] 
**ha_response_status_change_date** | **datetime** |  | [optional] 
**ha_response_details** | **str** |  | [optional] 
**promoter_response_status** | [**InspectionOutcomeStatusTypeResponse**](InspectionOutcomeStatusTypeResponse.md) |  | [optional] 
**promoter_response_status_string** | **str** |  | [optional] 
**promoter_response_status_change_date** | **datetime** |  | [optional] 
**promoter_response_details** | **str** |  | [optional] 
**is_auto_accepted** | **bool** |  | [optional] 
**non_compliance_reference_number** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

